// Persistence of Vision Ray Tracer Scene Description File
// File: *.pov
// Vers: 3.5
// Auth: Porrey

#version 3.5;

global_settings { assumed_gamma 2.2 max_trace_level 5 }


/*********************************************************************************************/
#declare Licht    = 1; // 1 = normal, 2 = Kerze
#declare Geschirr = 3; // 1 = Frhstck, 2 = Mittag, 3 = beides
/*********************************************************************************************/


#if (Licht=1)
#default { pigment { color rgb 1 } finish { ambient .4 diffuse .6 phong 0 } }
#end

#if (Licht=2)
#default { pigment { color rgb 1 } finish { ambient .2 diffuse .8 phong 0 } }
#end

#include "stdinc.inc"
#include "textures.inc"
#include "rp.inc" // "rp2.inc" = Bestandteil von rp.inc

#declare Direction = 2; // 1, 2, ...
#declare Camera_Position = <-20.0, 55.0,-45.0*Direction >;
#declare Camera_lookat =   <  0.0, 15.0,  0.0 >;

camera { location Camera_Position
         direction z*Direction up y right x*4/3
         look_at  Camera_lookat }

#if (Licht=1)	
light_source { Camera_Position color rgb < 0.9, 0.9, 1>*0.2 } // Blitzlicht
light_source	{ < 0, 90, 0 > Weiss }
#end

plane { y, 0 pigment { checker Weiss*0.9, Weiss*0.8 scale 10 } }
plane { y, 100 pigment { Weiss } hollow on }
//plane { x, 100 pigment { Weiss } hollow on }
//plane { x,-100 pigment { Weiss } }
//plane { z, 100 pigment { Weiss } hollow on }
//plane { z,-100 pigment { Weiss } }

#declare Textur_Geschirr =
texture {
  pigment { radial frequency 1 
    color_map {
      [ (1/4)*1 color rgb 1 ]
      [ (1/4)*2 color rgb < .45, .55, .65 > ]
      [ (1/4)*3 color rgb < .45, .55, .65 > ]
      [ (1/4)*4 color rgb 1 ] }
  turbulence 0 }
  finish { phong 1 reflection .1 }
  rotate y*-45
}

#declare Material_Glas =
material {
  texture {
    pigment { radial frequency 8 
      color_map {
      [ (1/4)*1 color rgbf < 0.95, 0.95, 0.95, 0.95 > ]
      [ (1/4)*2 color rgbf < 0.95, 0.95, 0.95, 0.25 > ]
      [ (1/4)*3 color rgbf < 0.95, 0.95, 0.95, 0.25 > ]
      [ (1/4)*4 color rgbf < 0.95, 0.95, 0.95, 0.95 > ] }
    turbulence 0 }
    finish { reflection .1 phong 1 }
  }
}

#declare Textur_m_Holz = texture { Yellow_Pine scale 50 rotate y*90 }


#include "metals.inc" // auch golds.inc 
#include "Geschirr_neu.inc" 
#include "Vase_neu.inc"
#include "Besteck_neu.inc" 
#include "Kerze_neu.inc"
#include "Moebel_neu.inc"


// Tasse (+Kaffee) auf Teller1 = y*0.3
// Teller1 auf Teller2         = y*0.4
// Teller3 auf Teller3         = y*0.4 
// Teller4 auf Teller3         = y*0.4
// Teller4 auf Teller4         = y*0.5
// Ei in Becher                = y*1.5
// Geschirr auf Tisch          = y*20

#declare Kaffee_in_Tasse = 1; // true/false, 1/0, on/off
#declare Saft_in_Glas    = 1; // true/false, 1/0, on/off
#declare Saft_in_Karaffe = 1; // true/false, 1/0, on/off
#declare Loeffel1_auf_Teller1 = transform { rotate <.8,-5,8> translate <3,.7,-4>   } // Teelffel auf Kaffeteller
#declare Loeffel2_auf_Teller4 = transform { rotate <11,-25,0,> translate <3,2,-7,> } // Esslffel auf Suppenteller


#declare Fruehstueck =
union { // Frhstcksgeschirr
  union { // Tasse+Kaffee
    object { Tasse  translate <0,0.3,0> }
    #if (Kaffee_in_Tasse=true) object { Kaffee translate <0,0.3,0> } #end
    object { Teller1 }
    object { b_Loeffel1 transform { Loeffel1_auf_Teller1 } }
    translate <7,0,9>
  }
  object { Teller2 }
  object { b_Gabel  translate <-6,0,-5> }
  object { b_Messer translate < 6,0,-5> }
  union {
    object { Eierbecher }
    object { Ei translate <0,1.5,0> }
    translate < 0,0,8>
  }
}

#declare Mittag =
union {
  object { Teller3 }
  union {
    object { Teller4 }
    object { b_Loeffel2 transform { Loeffel2_auf_Teller4 } }
    translate <0,0.4,0>
  }
  object { b_Gabel    translate <-8,0,-5> }
  object { b_Messer   translate < 8,0,-5> }
  object { b_Loeffel1 translate < 0,0,-3> rotate y*-90 translate < 0,0,8> }
  union {
    object { Glas }
    #if (Saft_in_Glas=true) object { Saft1 } #end
    translate <7,0,9>
  }
}

#if (Geschirr=1)
union {

  object { Fruehstueck translate <0,0,-22> rotate y*0   }
  object { Fruehstueck translate <0,0,-22> rotate y*90  }
  object { Fruehstueck translate <0,0,-22> rotate y*180 }
  object { Fruehstueck translate <0,0,-22> rotate y*-90 }
  union {
    object { Kanne }
    object { Deckel }
    scale 1.1
  translate < -4,0,-8>
  }

  union {
    object { v_Vase rotate y*-90 }
    object { v_Gruen }
    object { v_Pollen }
    object { v_Bluete }
  scale 1.2
  rotate y*90
  translate < 0,0,0>
  }

translate y*20
}#end

#if (Geschirr=2)
union {

  object { Mittag translate <0,0,-21> rotate y*0   }
  object { Mittag translate <0,0,-21> rotate y*90  }
  object { Mittag translate <0,0,-21> rotate y*180 }
  object { Mittag translate <0,0,-21> rotate y*-90 }
  union {
    object { Karaffe }
    #if (Saft_in_Karaffe=true) object { Saft2 } #end
  translate < 4, 0, 8>
  }

  union {
    object { v_Vase rotate y*-90 }
    object { v_Gruen }
    object { v_Pollen }
    object { v_Bluete }
  scale 1.2
  rotate y*90
  translate < 0,0,0>
  }

translate y*20
}#end

#if (Geschirr=3)
union {

  object { Fruehstueck translate <0,0,-22> rotate y*0   }
  object { Fruehstueck translate <0,0,-22> rotate y*-90 }
  union {
    object { Kanne }
    object { Deckel }
    scale 1.1
  translate < -4,0,-8>
  }

  object { Mittag translate <0,0,-21> rotate y*90  }
  object { Mittag translate <0,0,-21> rotate y*180 }
  union {
    object { Karaffe }
    #if (Saft_in_Karaffe=true) object { Saft2 } #end
  translate < 4, 0, 8>
  }

  union {
    object { v_Vase rotate y*-90 }
    object { v_Gruen }
    object { v_Pollen }
    object { v_Bluete }
  scale 1.2
  rotate y*90
  translate < 0,0,0>
  }

translate y*20
}#end



object { m_Tischplatte }
object { m_Tischfuss }


#local Flammenhoehe = 12.5;
#local StandortX = 16;
#local StandortY = 20;
#local StandortZ = 16;
object { Kerzenhalter translate <StandortX,StandortY,StandortZ> }
object { Kerze translate <StandortX,StandortY,StandortZ> }
object { Kerzendocht translate <StandortX,StandortY,StandortZ> }
#if (Licht=2)
object { Flamme scale 5 translate < StandortX, Flammenhoehe+StandortY, StandortZ> }
#declare camera_location = Camera_Position; #declare camera_look_at = Camera_lookat; #declare effect_location = < StandortX, Flammenhoehe+0.4+StandortY, StandortZ>; #declare effect_scale = .3; #declare effect_intensity = .75 ; #declare effect_type = "CANDLE" #include "LENS.INC"
#end

#local Flammenhoehe = 12.5;
#local StandortX = -16;
#local StandortY =  20;
#local StandortZ =  16;
object { Kerzenhalter translate <StandortX,StandortY,StandortZ> }
object { Kerze translate <StandortX,StandortY,StandortZ> }
object { Kerzendocht translate <StandortX,StandortY,StandortZ> }
#if (Licht=2)
object { Flamme scale 5 translate < StandortX, Flammenhoehe+StandortY, StandortZ> }
#declare camera_location = Camera_Position; #declare camera_look_at = Camera_lookat; #declare effect_location = < StandortX, Flammenhoehe+0.4+StandortY, StandortZ>; #declare effect_scale = .3; #declare effect_intensity = .75 ; #declare effect_type = "CANDLE" #include "LENS.INC"
#end

#local Flammenhoehe = 12.5;
#local StandortX =  16;
#local StandortY =  20;
#local StandortZ = -16;
object { Kerzenhalter translate <StandortX,StandortY,StandortZ> }
object { Kerze translate <StandortX,StandortY,StandortZ> }
object { Kerzendocht translate <StandortX,StandortY,StandortZ> }
#if (Licht=2)
object { Flamme scale 5 translate < StandortX, Flammenhoehe+StandortY, StandortZ> }
#declare camera_location = Camera_Position; #declare camera_look_at = Camera_lookat; #declare effect_location = < StandortX, Flammenhoehe+0.4+StandortY, StandortZ>; #declare effect_scale = .3; #declare effect_intensity = .75 ; #declare effect_type = "CANDLE" #include "LENS.INC"
#end

#local Flammenhoehe = 12.5;
#local StandortX = -16;
#local StandortY =  20;
#local StandortZ = -16;
object { Kerzenhalter translate <StandortX,StandortY,StandortZ> }
object { Kerze translate <StandortX,StandortY,StandortZ> }
object { Kerzendocht translate <StandortX,StandortY,StandortZ> }
#if (Licht=2)
object { Flamme scale 5 translate < StandortX, Flammenhoehe+StandortY, StandortZ> }
#declare camera_location = Camera_Position; #declare camera_look_at = Camera_lookat; #declare effect_location = < StandortX, Flammenhoehe+0.4+StandortY, StandortZ>; #declare effect_scale = .3; #declare effect_intensity = .75 ; #declare effect_type = "CANDLE" #include "LENS.INC"
#end

