/* RP2.inc (Bestandteil von RP.inc) -
   Farben, (Texturen, Finishes) in deutscher Sprache,
   dazu einige Shapes (bentigt "Shapes.inc")
*/

// ====================================================== Sky by F. Lohmueller
#declare Lo_Sky = union {

plane { y, 10000 hollow
  texture {
    pigment { color rgb < 0.2, 0.5, 0.8 > }
    finish { ambient 1 diffuse 0 }
  }
}
plane { y, 1 hollow
  texture {
    pigment { bozo turbulence 0.65
                   octaves 6  omega 0.7 lambda 2 
                   color_map { [0.0 color rgb <0.95, 0.95, 0.95>]
                               [0.1 color rgb <0.85, 0.85, 0.85>]
                               [0.5 color rgbt <1, 1, 1, 1> ]
                               [1.0 color rgbt <1, 1, 1, 1> ]   }
                   rotate<10,20,0>
                   scale <0.3, 0.4, 0.2>*3
             }
    finish { ambient 1 diffuse 0 }
  }
scale 1000 }  
}
// ====================================================== Ende Lo_Sky

#declare Box_oben   = box { <-100, 0.001,-100>, 100 }
#declare Box_unten  = box {-100, < 100,-0.001, 100> }
#declare Box_links  = box {-100, <-0.001, 100, 100> }
#declare Box_rechts = box { < 0.001,-100,-100>, 100 }
#declare Box_vorn   = box {-100, < 100, 100,-0.001> }
#declare Box_hinten = box { <-100,-100, 0.001>, 100 }

#declare Spiegel = finish { ambient 0 diffuse 0 phong 0 reflection 1 }

#declare RP_Glas1 =  // Material: einfaches Glas mit ior
 material {
  texture {
   pigment {color rgbf < .9, .95, .9, .9 >}
   finish { reflection .1 phong 1 }
  }
  interior { ior 1.1 }
 }

#declare RP_Glas2 =  // Material: einfaches Glas
 material {
  texture {
   pigment {color rgbf < 1, 1, 1, .8 >}
   finish { reflection .1 phong 1 }
  }
 }

#declare RP_Wasser1 = // Textur: Wasser
 texture { pigment { color rgbf < .1, .3, .5, .9 > }
           normal { bumps .1 scale 1 } finish { phong 1 reflection .5 } }

// ====================================================== Himmel
#declare P_Cloud4rp =
pigment {
    wrinkles
    turbulence 0.1
    lambda 2.2
    omega 0.707
    color_map {
        [0.20 SkyBlue * 0.85 ]
        [0.50 White ]
        [1.00 Gray70 ]
    }
    scale <0.5, 0.15, 1>
}

#declare S_Cloud2rp =
sky_sphere {
    pigment {
        gradient y
        pigment_map {
//            [0.00 rgb <0.847, 0.749, 0.847> ] // horizon 
            [0.00 SkyBlue*.9 ]                   // horizon           
            [0.01 SkyBlue ]                   // horizon
            [0.20 P_Cloud4rp ]
        }
    }
}

// ====================================================== Marmor (Pigment und Textur)
#declare Marmor_Map_rp =
 color_map {
    [.0,  .7 color rgb <.91, .9, .89> color rgb <.55, .5, .45>]
    [.7, 1.0 color rgb <.55, .5, .45> color rgb <.20, .1, .00>] }

#declare Marmor_Marble_rp =
 pigment { marble turbulence 1 color_map { Marmor_Map_rp } }

// pigment
#declare Marmor_rp = pigment { Marmor_Marble_rp scale 2 }

// texture
#declare Marmor_rp_tex = texture {
pigment { Marmor_rp } finish { reflection .3 } }


// ====================================================== Tropfen / Ei
#declare Winkel_des_Konus = radians(30);        // normal = ca. 30
#declare Radius_der_Kugel =  1;                 // normal = ca.  1
#declare Segment_Hoehe    = sin(Winkel_des_Konus)*Radius_der_Kugel;
#declare Segment_Radius   = cos(Winkel_des_Konus)*Radius_der_Kugel;
#declare Kegel_Hoehe      = Segment_Radius/tan(Winkel_des_Konus);

#declare Tropfen =
  merge { // union ohne Schnittmenge fuer "durchsichtig" - z.B. Wasser
    sphere { 0, Radius_der_Kugel }
    cone { y*0, Segment_Radius, y*Kegel_Hoehe, 0 translate y*Segment_Hoehe }
  }

// ====================================================== Ei
#declare Ei = union { difference {
 sphere { 0, 1 scale < 1.0, 2.0, 1.0 > } object { Box_unten } }
 difference { sphere { 0, 1 } object { Box_oben } } }

#declare Ttiefe = .2 ;

#declare Tropfen_flach = union { difference {
  cylinder { z*-Ttiefe, z*Ttiefe, 1 }
  box { <-5,0.5001,-5>, 5 } }
 difference {
  box { <-5,-1.5,-Ttiefe >, < 5, 0, Ttiefe > }
  box { < 0,-5,-5 >, 5 rotate z*30 }
  box { -5, < 0, 5, 5 > rotate z*-30 } translate y*2} }

#declare Ei_flach = union { difference {
 cylinder { z*-Ttiefe, z*Ttiefe, 1 scale < 1.0, 2.0, 1.0 > } object { Box_unten } }
 difference { cylinder { z*-Ttiefe, z*Ttiefe, 1 } object { Box_oben } } }

// ====================================================== Herzen
#declare Herz11 = union {
  object { Tropfen rotate z*180 translate y*2 rotate z*20 }
  object { Tropfen rotate z*180 translate y*2 rotate z*-20 }
  scale <1,1,.5> translate y*-1.5 }

#declare Herz12 = union { // flach
 object { Tropfen_flach rotate z*180 translate y*2 rotate z*20 }
 object { Tropfen_flach rotate z*180 translate y*2 rotate z*-20 }
translate y*-1.5 }

#declare Halb1 = difference { union {
  object { Tropfen rotate z*180 translate y*2 rotate z*20 }
  object { Tropfen rotate z*180 translate y*2 rotate z*-20 }
  scale <1,1,.5> }
 object { Box_hinten } }

#declare Herz13 = union {
 object { Halb1 translate z*-Ttiefe }
 object { Halb1 translate z*-Ttiefe rotate y*180 }
 object { Tropfen_flach rotate z*180 translate y*2 rotate z*20 }
 object { Tropfen_flach rotate z*180 translate y*2 rotate z*-20 }
translate y*-1.5}

#declare Herz21 = union {
  object { Ei rotate z*180 translate y*1.5 rotate z*30 }
  object { Ei rotate z*180 translate y*1.5 rotate z*-30 }
  scale <1,1,.5> translate y*-1.0 }

#declare Herz22 = union { // flach
 object { Ei_flach rotate z*180 translate y*1.5 rotate z*30 }
 object { Ei_flach rotate z*180 translate y*1.5 rotate z*-30 }
translate y*-1.0 }

#declare Halb2 = difference { union {
  object { Ei rotate z*180 translate y*1.5 rotate z*30 }
  object { Ei rotate z*180 translate y*1.5 rotate z*-30 }
  scale <1,1,.5> }
 object { Box_hinten } }

#declare Herz23 = union {
 object { Halb2 translate z*-Ttiefe }
 object { Halb2 translate z*-Ttiefe rotate y*180 }

 object { Ei_flach rotate z*180 translate y*1.5 rotate z*30 }
 object { Ei_flach rotate z*180 translate y*1.5 rotate z*-30 }
translate y*-1.0 }


// ====================================================== Extra_Tropfen
#declare Radius_Tropfen = 1 ;
#declare Wert_Tropfen = Radius_Tropfen*sqrt(2)*.5 ;
#declare Extra_Tropfen =
union {
// difference {
  sphere { 0, Radius_Tropfen }
//  box { <-5, Wert_Tropfen,-5 >, 5 } // oben
//  box {-5, < 5,-Wert_Tropfen, 5 > } // unten
//  box { < Wert_Tropfen,-5,-5 >, 5 } // rechts
//  box {-5, <-Wert_Tropfen, 5, 5 > } // links
//  box { < 5,-5, Wert_Tropfen >, 5 } // hinten
//  box {-5, < 5, 5,-Wert_Tropfen > } // vorn
//  } // Ende difference
 cone { y*Wert_Tropfen*2, 0, y*Wert_Tropfen, Wert_Tropfen } // oben
 cone { y*Wert_Tropfen*2, 0, y*Wert_Tropfen, Wert_Tropfen rotate z*180 } // unten
 cone { y*Wert_Tropfen*2, 0, y*Wert_Tropfen, Wert_Tropfen rotate z*-90 } // rechts
 cone { y*Wert_Tropfen*2, 0, y*Wert_Tropfen, Wert_Tropfen rotate z*90  } // links
 cone { y*Wert_Tropfen*2, 0, y*Wert_Tropfen, Wert_Tropfen rotate x*90  } // hinten
 cone { y*Wert_Tropfen*2, 0, y*Wert_Tropfen, Wert_Tropfen rotate x*-90 } // vorn
 } // Ende union

#declare Fadenkreuz_x1y1 = union{
 object { Cylinder_X scale <1,.025,.025> translate y*1 }
 object { Cylinder_X scale <1,.025,.025> translate y*-1 }
 object { Cylinder_Y scale <.025,1,.025> translate x*1 }
 object { Cylinder_Y scale <.025,1,.025> translate x*-1 }
 pigment { color rgb <2,0,0> } no_shadow }
#declare Fadenkreuz_xyz = union{
 object { Cylinder_X scale <1,.025,.025> }
 object { Cylinder_Y scale <.025,1,.025> }
 object { Cylinder_Z scale <.025,.025,1> }
 pigment { color rgb <2,0,0> } finish { phong 0 } no_shadow }
#declare Fadenkreuz_x =
 object { Cylinder_X scale <1,.025,.025>
 pigment { color rgb <2,0,0> } finish { phong 0 } no_shadow }
#declare Fadenkreuz_y =
 object { Cylinder_Y scale <.025,1,.025>
 pigment { color rgb <2,0,0> } finish { phong 0 } no_shadow }
#declare Fadenkreuz_z =
 object { Cylinder_Z scale <.025,.025,1>
 pigment { color rgb <2,0,0> } finish { phong 0 } no_shadow }
#declare Fadenkreuz_xy = union{
 object { Cylinder_X scale <1,.025,.025> }
 object { Cylinder_Y scale <.025,1,.025> }
 pigment { color rgb <2,0,0> } finish { phong 0 } no_shadow }
#declare Fadenkreuz_xz = union{
 object { Cylinder_X scale <1,.025,.025> }
 object { Cylinder_Z scale <.025,.025,1> }
 pigment { color rgb <2,0,0> } finish { phong 0 } no_shadow }
#declare Fadenkreuz_yz = union{
 object { Cylinder_Y scale <.025,1,.025> }
 object { Cylinder_Z scale <.025,.025,1> }
 pigment { color rgb <2,0,0> } finish { phong 0 } no_shadow }


// ====================================================== ColorMap
#declare Color_Map_RP_1 = color_map {
[ (1/12)*1 Rot ]
[ (1/12)*2 Rot_Gelb ]
[ (1/12)*3 Gelb ]
[ (1/12)*4 Gruen_Gelb ]
[ (1/12)*5 Gruen ]
[ (1/12)*6 Gruen_Hellblau ]
[ (1/12)*7 Hellblau ]
[ (1/12)*8 Blau_Hellblau ]
[ (1/12)*9 Blau ]
[ (1/12)*10 Blau_Lila ]
[ (1/12)*11 Lila ]
[ (1/12)*12 Rot_Lila ]
}

#declare Color_Map_RP_2 = color_map { // original frequency
[ (1/13)*1 color rgb  < 1.00, 0.00, 1.00 > ]
[ (1/13)*2 color rgb  < 1.00, 0.25, 0.75 > ]
[ (1/13)*3 color rgb  < 1.00, 0.50, 0.50 > ]
[ (1/13)*4 color rgb  < 1.00, 0.75, 0.25 > ]
[ (1/13)*5 color rgb  < 1.00, 1.00, 0.00 > ]
[ (1/13)*6 color rgb  < 0.75, 1.00, 0.25 > ]
[ (1/13)*7 color rgb  < 0.50, 1.00, 0.50 > ]
[ (1/13)*8 color rgb  < 0.25, 1.00, 0.75 > ]
[ (1/13)*9 color rgb  < 0.00, 1.00, 1.00 > ]
[ (1/13)*10 color rgb < 0.25, 0.75, 1.00 > ]
[ (1/13)*11 color rgb < 0.50, 0.50, 1.00 > ]
[ (1/13)*12 color rgb < 0.75, 0.25, 1.00 > ]
[ (1/13)*13 color rgb < 1.00, 0.00, 1.00 > ]
}

#declare Color_Map_RP_3 = color_map {
[ (1/25)*1  color rgb  < 1.00, 0.00, 0.00 > ]
[ (1/25)*2  color rgb  < 1.00, 0.25, 0.00 > ]
[ (1/25)*3  color rgb  < 1.00, 0.50, 0.00 > ]
[ (1/25)*4  color rgb  < 1.00, 0.75, 0.00 > ]
[ (1/25)*5  color rgb  < 1.00, 1.00, 0.00 > ]
[ (1/25)*6  color rgb  < 0.75, 1.00, 0.00 > ]
[ (1/25)*7  color rgb  < 0.50, 1.00, 0.00 > ]
[ (1/25)*8  color rgb  < 0.25, 1.00, 0.00 > ]
[ (1/25)*9  color rgb  < 0.00, 1.00, 0.00 > ]
[ (1/25)*10 color rgb  < 0.00, 1.00, 0.25 > ]
[ (1/25)*11 color rgb  < 0.00, 1.00, 0.50 > ]
[ (1/25)*12 color rgb  < 0.00, 1.00, 0.75 > ]
[ (1/25)*13 color rgb  < 0.00, 1.00, 1.00 > ]
[ (1/25)*14 color rgb  < 0.00, 0.75, 1.00 > ]
[ (1/25)*15 color rgb  < 0.00, 0.50, 1.00 > ]
[ (1/25)*16 color rgb  < 0.00, 0.25, 1.00 > ]
[ (1/25)*17 color rgb  < 0.00, 0.00, 1.00 > ]
[ (1/25)*18 color rgb  < 0.25, 0.00, 1.00 > ]
[ (1/25)*19 color rgb  < 0.50, 0.00, 1.00 > ]
[ (1/25)*20 color rgb  < 0.75, 0.00, 1.00 > ]
[ (1/25)*21 color rgb  < 1.00, 0.00, 1.00 > ]
[ (1/25)*22 color rgb  < 1.00, 0.00, 0.75 > ]
[ (1/25)*23 color rgb  < 1.00, 0.00, 0.50 > ]
[ (1/25)*24 color rgb  < 1.00, 0.00, 0.25 > ]
[ (1/25)*25 color rgb  < 1.00, 0.00, 0.00 > ]
}

#declare Color_Map_a1 = color_map { [ 0 Rot      ] [ 1 Gelb     ] }
#declare Color_Map_a2 = color_map { [ 0 Gelb     ] [ 1 Gruen    ] }
#declare Color_Map_a3 = color_map { [ 0 Gruen    ] [ 1 Hellblau ] }
#declare Color_Map_a4 = color_map { [ 0 Hellblau ] [ 1 Blau     ] }
#declare Color_Map_a5 = color_map { [ 0 Blau     ] [ 1 Lila     ] }
#declare Color_Map_a6 = color_map { [ 0 Lila     ] [ 1 Rot      ] }
#declare Color_Map_a7 = color_map { [ 0 Haut     ] [ 1 Weiss    ] }
#declare Color_Map_a8 = color_map { [ 0 Klar     ] [ 1 Haut     ] }

#declare Color_Map_b1 = color_map { [ 0 Rot      ] [ .3 Gelb     ] [ .6 Gelb     ] [ 1 Rot      ] }
#declare Color_Map_b2 = color_map { [ 0 Gelb     ] [ .3 Gruen    ] [ .6 Gruen    ] [ 1 Gelb     ] }
#declare Color_Map_b3 = color_map { [ 0 Gruen    ] [ .3 Hellblau ] [ .6 Hellblau ] [ 1 Gruen    ] }
#declare Color_Map_b4 = color_map { [ 0 Hellblau ] [ .3 Blau     ] [ .6 Blau     ] [ 1 Hellblau ] }
#declare Color_Map_b5 = color_map { [ 0 Blau     ] [ .3 Lila     ] [ .6 Lila     ] [ 1 Blau     ] }
#declare Color_Map_b6 = color_map { [ 0 Lila     ] [ .3 Rot      ] [ .6 Rot      ] [ 1 Lila     ] }
#declare Color_Map_b7 = color_map { [ 0 Haut     ] [ .3 Weiss    ] [ .6 Weiss    ] [ 1 Haut     ] }
#declare Color_Map_b8 = color_map { [ 0 Klar     ] [ .3 Haut     ] [ .6 Haut     ] [ 1 Klar     ] }

// Rainbow-Colors (aus: Rainbow.inc)
#declare r_violet1 = color red 1.0 green 0.5 blue 1.0 filter 1.0 ;
#declare r_violet2 = color red 1.0 green 0.5 blue 1.0 filter 0.8 ;
#declare r_indigo  = color red 0.5 green 0.5 blue 1.0 filter 0.8 ;
#declare r_blue    = color red 0.2 green 0.2 blue 1.0 filter 0.8 ;
#declare r_cyan    = color red 0.2 green 1.0 blue 1.0 filter 0.8 ;
#declare r_green   = color red 0.2 green 1.0 blue 0.2 filter 0.8 ;
#declare r_yellow  = color red 1.0 green 1.0 blue 0.2 filter 0.8 ;
#declare r_orange  = color red 1.0 green 0.5 blue 0.2 filter 0.8 ;
#declare r_red1    = color red 1.0 green 0.2 blue 0.2 filter 0.8 ;
#declare r_red2    = color red 1.0 green 0.2 blue 0.2 filter 1.0 ;

#declare Rainbow_1 = color_map { // Original
[0.000  color r_violet1 ]
[0.100  color r_violet2 ]
[0.214  color r_indigo  ]
[0.328  color r_blue    ]
[0.442  color r_cyan    ]
[0.556  color r_green   ]
[0.670  color r_yellow  ]
[0.784  color r_orange  ]
[0.900  color r_red1    ] }

#declare Rainbow_2 = color_map { // by Porrey
[ (1/10)*1  r_violet1 ]
[ (1/10)*2  r_violet2 ]
[ (1/10)*3  r_indigo  ]
[ (1/10)*4  r_blue    ]
[ (1/10)*5  r_cyan    ]
[ (1/10)*6  r_green   ]
[ (1/10)*7  r_yellow  ]
[ (1/10)*8  r_orange  ]
[ (1/10)*9  r_red1    ]
[ (1/10)*10 r_red2    ] }

#declare Starfield_RP = sky_sphere { pigment { granite color_map {
 [ 0.000  0.270 color rgb < 0, 0, 0> color rgb < 0, 0, 0> ]
 [ 0.270  0.285 color rgb <.5,.5,.4> color rgb <.8,.8,.4> ]
 [ 0.285  0.470 color rgb < 0, 0, 0> color rgb < 0, 0, 0> ]
 [ 0.470  0.485 color rgb <.4,.4,.5> color rgb <.4,.4,.8> ]
 [ 0.485  0.680 color rgb < 0, 0, 0> color rgb < 0, 0, 0> ]
 [ 0.680  0.695 color rgb <.5,.4,.4> color rgb <.8,.4,.4> ]
 [ 0.695  0.880 color rgb < 0, 0, 0> color rgb < 0, 0, 0> ]
 [ 0.880  0.895 color rgb <.5,.5,.5> color rgb < 1, 1, 1> ]
 [ 0.895  1.000 color rgb < 0, 0, 0> color rgb < 0, 0, 0> ] }
    turbulence 1 sine_wave scale .5 } }
